summaryrefslogtreecommitdiff
path: root/t/t9300-fast-import.sh
diff options
context:
space:
mode:
authorRichard Hansen <rhansen@bbn.com>2013-09-04 19:04:31 (GMT)
committerJunio C Hamano <gitster@pobox.com>2013-09-04 22:03:03 (GMT)
commita8a5406ab32fccabf8ed08001d50b5373e18ff1a (patch)
tree82ec0a98750812e269b935eb369671ad84be8b45 /t/t9300-fast-import.sh
parentbb8040f9f9274d739b894230959134584b156ae5 (diff)
downloadgit-a8a5406ab32fccabf8ed08001d50b5373e18ff1a.zip
git-a8a5406ab32fccabf8ed08001d50b5373e18ff1a.tar.gz
git-a8a5406ab32fccabf8ed08001d50b5373e18ff1a.tar.bz2
use 'commit-ish' instead of 'committish'
Replace 'committish' in documentation and comments with 'commit-ish' to match gitglossary(7) and to be consistent with 'tree-ish'. The only remaining instances of 'committish' are: * variable, function, and macro names * "(also committish)" in the definition of commit-ish in gitglossary[7] Signed-off-by: Richard Hansen <rhansen@bbn.com> Signed-off-by: Junio C Hamano <gitster@pobox.com>
Diffstat (limited to 't/t9300-fast-import.sh')
-rwxr-xr-xt/t9300-fast-import.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/t/t9300-fast-import.sh b/t/t9300-fast-import.sh
index ac6f3b6..a74b9cf 100755
--- a/t/t9300-fast-import.sh
+++ b/t/t9300-fast-import.sh
@@ -2815,14 +2815,14 @@ test_expect_success 'S: notemodify with garbage after sha1 dataref must fail' '
'
#
# notemodify, mark in committish
#
-test_expect_success 'S: notemodify with garbarge after mark committish must fail' '
+test_expect_success 'S: notemodify with garbarge after mark commit-ish must fail' '
test_must_fail git fast-import --import-marks=marks <<-EOF 2>err &&
commit refs/heads/Snotes
committer $GIT_COMMITTER_NAME <$GIT_COMMITTER_EMAIL> $GIT_COMMITTER_DATE
data <<COMMIT
- commit S note committish
+ commit S note commit-ish
COMMIT
N :202 :302x
EOF
@@ -2815,14 +2815,14 @@ test_expect_success 'S: notemodify with garbage after sha1 dataref must fail' '
'
#
-# notemodify, mark in committish
+# notemodify, mark in commit-ish
#